@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for codeguruprofiler service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_codeguruprofiler import CodeGuruProfilerClient
-    from mypy_boto3_codeguruprofiler import (
+    from mypy_boto3_codeguruprofiler.paginator import (
         ListProfileTimesPaginator,
     )
 
@@ -16,11 +17,12 @@ Usage::
     list_profile_times_paginator: ListProfileTimesPaginator = client.get_paginator("list_profile_times")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Iterator, TYPE_CHECKING
+from datetime import datetime
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_codeguruprofiler.type_defs import (
     ListProfileTimesResponseTypeDef,
     PaginatorConfigTypeDef,
@@ -37,7 +39,7 @@ __all__ = ("ListProfileTimesPaginator",)
 
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
     """
 
     def paginate(
@@ -50,5 +52,5 @@ class ListProfileTimesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProfileTimesResponseTypeDef]:
         """
-        [ListProfileTimes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [ListProfileTimes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         """
